From b5681d33243e5a781551116e9916c30917277a03 Mon Sep 17 00:00:00 2001
From: Rahil Doshi <rahil.doshi@fau.de>
Date: Tue, 18 Mar 2025 17:13:49 +0100
Subject: [PATCH] Rename atomic mass unit to amu

---
 src/pymatlib/data/constants.py    |  4 ++--
 src/pymatlib/data/element_data.py | 26 +++++++++++++-------------
 2 files changed, 15 insertions(+), 15 deletions(-)

diff --git a/src/pymatlib/data/constants.py b/src/pymatlib/data/constants.py
index c819919..897e370 100644
--- a/src/pymatlib/data/constants.py
+++ b/src/pymatlib/data/constants.py
@@ -9,12 +9,12 @@ class Constants:
     Attributes:
         temperature_room (float): Room temperature in Kelvin.
         N_a (float): Avogadro's number, the number of constituent particles (usually atoms or molecules) in one mole of a given substance.
         u (float): Atomic mass unit in kilograms.
         e (float): Elementary charge, the electric charge carried by a single proton or the magnitude of the electric charge carried by a single electron.
         speed_of_light (float): Speed of light in vacuum in meters per second.
     """
     temperature_room: float = 298.15  # Room temperature in Kelvin
     N_a: float = 6.022141e23  # Avogadro's number, /mol
-    u: float = 1.660538e-27  # Atomic mass unit, kg
+    amu: float = 1.660538e-27  # Atomic mass unit, kg
     e: float = 1.60217657e-19  # Elementary charge, C
     speed_of_light: float = 0.299792458e9  # Speed of light, m/s
@@ -9,12 +9,12 @@ class Constants:
         temperature_room (float): Room temperature in Kelvin.
         N_a (float): Avogadro's number, the number of constituent particles (usually atoms or molecules) in one mole of a given substance.
-        u (float): Atomic mass unit in kilograms.
+        amu (float): Atomic mass unit in kilograms.
         e (float): Elementary charge, the electric charge carried by a single proton or the magnitude of the electric charge carried by a single electron.
         speed_of_light (float): Speed of light in vacuum in meters per second.
diff --git a/src/pymatlib/data/element_data.py b/src/pymatlib/data/element_data.py
index 75f035b..18ce7e4 100644
--- a/src/pymatlib/data/element_data.py
+++ b/src/pymatlib/data/element_data.py
@@ -8,7 +8,7 @@ from pymatlib.core.elements import ChemicalElement
 C = ChemicalElement(
     name="Carbon",
     atomic_number=6,
-    atomic_mass=12.0107 * Constants.u,
+    atomic_mass=12.0107 * Constants.amu,
     temperature_melt=3915,  # Melting temperature = 3915 K
     temperature_boil=4300,  # Boiling temperature = 4300 K
     latent_heat_of_fusion=117000,  # Latent heat of fusion = 117 kJ/mol
@@ -18,7 +18,7 @@ C = ChemicalElement(
 N = ChemicalElement(
     name="Nitrogen",
     atomic_number=7,
-    atomic_mass=14.0067 * Constants.u,
+    atomic_mass=14.0067 * Constants.amu,
     temperature_melt=63.15,  # Melting temperature = 63.15 K
     temperature_boil=77.36,  # Boiling temperature = 77.36 K
     latent_heat_of_fusion=720,  # Latent heat of fusion = 0.72 kJ/mol
@@ -28,7 +28,7 @@ N = ChemicalElement(
 Al = ChemicalElement(
     name="Aluminium",
     atomic_number=13,  # Atomic number = 13 / Source: Periodic Table
-    atomic_mass=26.9815384 * Constants.u,  # Atomic mass = 26.9815384 u / Source: NIST
+    atomic_mass=26.9815384 * Constants.amu,  # Atomic mass = 26.9815384 amu / Source: NIST
     temperature_melt=933.35,  # Melting temperature = 933.35 K / Source: RSC
     temperature_boil=2743,  # Boiling temperature = 2743 K / Source: RSC
     latent_heat_of_fusion=10700,  # Latent heat of fusion = 10700 J/kg / Source: CRC
@@ -38,7 +38,7 @@ Al = ChemicalElement(
 Si = ChemicalElement(
     name="Silicon",
     atomic_number=14,
-    atomic_mass=28.0855 * Constants.u,
+    atomic_mass=28.0855 * Constants.amu,
     temperature_melt=1687,  # Melting temperature = 1687 K
     temperature_boil=3538,  # Boiling temperature = 3538 K
     latent_heat_of_fusion=50200,  # Latent heat of fusion = 50.2 kJ/mol
@@ -48,7 +48,7 @@ Si = ChemicalElement(
 P = ChemicalElement(
     name="Phosphorus",
     atomic_number=15,
-    atomic_mass=30.973762 * Constants.u,
+    atomic_mass=30.973762 * Constants.amu,
     temperature_melt=317.3,  # Melting temperature = 317.3 K
     temperature_boil=553.7,  # Boiling temperature = 553.7 K
     latent_heat_of_fusion=2510,  # Latent heat of fusion = 2.51 kJ/mol
@@ -58,7 +58,7 @@ P = ChemicalElement(
 S = ChemicalElement(
     name="Sulfur",
     atomic_number=16,
-    atomic_mass=32.065 * Constants.u,
+    atomic_mass=32.065 * Constants.amu,
     temperature_melt=388.36,  # Melting temperature = 388.36 K
     temperature_boil=717.8,  # Boiling temperature = 717.8 K
     latent_heat_of_fusion=1730,  # Latent heat of fusion = 1.73 kJ/mol
@@ -68,7 +68,7 @@ S = ChemicalElement(
 Ti = ChemicalElement(
     name="Titanium",
     atomic_number=22,  # Atomic number = 22 / Source: Periodic Table
-    atomic_mass=47.867 * Constants.u,  # Atomic mass = 47.867 u / Source: NIST
+    atomic_mass=47.867 * Constants.amu,  # Atomic mass = 47.867 amu / Source: NIST
     temperature_melt=1941,  # Melting temperature = 1941 K / Source: RSC
     temperature_boil=3560,  # Boiling temperature = 3560 K / Source: RSC
     latent_heat_of_fusion=18700,  # Latent heat of fusion = 18700 J/kg / Source: CRC
@@ -78,7 +78,7 @@ Ti = ChemicalElement(
 V = ChemicalElement(
     name="Vanadium",
     atomic_number=23,  # Atomic number = 23 / Source: Periodic Table
-    atomic_mass=50.9415 * Constants.u,  # Atomic mass = 50.9415 u / Source: NIST
+    atomic_mass=50.9415 * Constants.amu,  # Atomic mass = 50.9415 amu / Source: NIST
     temperature_melt=2183,  # Melting temperature = 2183 K / Source: RSC
     temperature_boil=3680,  # Boiling temperature = 3680 K / Source: RSC
     latent_heat_of_fusion=21500,  # Latent heat of fusion = 21500 J/kg / Source: CRC
@@ -88,7 +88,7 @@ V = ChemicalElement(
 Cr = ChemicalElement(
     name="Chromium",
     atomic_number=24,  # Atomic number = 24 / Source: Periodic Table
-    atomic_mass=51.9961 * Constants.u,  # Atomic mass = 51.9961 u / Source: NIST
+    atomic_mass=51.9961 * Constants.amu,  # Atomic mass = 51.9961 amu / Source: NIST
     temperature_melt=2180,  # Melting temperature = 2180 K / Source: RSC
     temperature_boil=2944,  # Boiling temperature = 2944 K / Source: RSC
     latent_heat_of_fusion=16500,  # Latent heat of fusion = 16500 J/kg / Source: CRC
@@ -98,7 +98,7 @@ Cr = ChemicalElement(
 Mn = ChemicalElement(
     name="Manganese",
     atomic_number=25,  # Atomic number = 25 / Source: Periodic Table
-    atomic_mass=54.938045 * Constants.u,  # Atomic mass = 54.938045 u / Source: NIST
+    atomic_mass=54.938045 * Constants.amu,  # Atomic mass = 54.938045 amu / Source: NIST
     temperature_melt=1519,  # Melting temperature = 1519 K / Source: RSC
     temperature_boil=2334,  # Boiling temperature = 2334 K / Source: RSC
     latent_heat_of_fusion=12500,  # Latent heat of fusion = 12500 J/kg / Source: CRC
@@ -108,7 +108,7 @@ Mn = ChemicalElement(
 Fe = ChemicalElement(
     name="Iron",
     atomic_number=26,  # Atomic number = 26 / Source: Periodic Table
-    atomic_mass=55.845 * Constants.u,  # Atomic mass = 55.845 u / Source: NIST
+    atomic_mass=55.845 * Constants.amu,  # Atomic mass = 55.845 amu / Source: NIST
     temperature_melt=1809,  # Melting temperature = 1809 K / Source: RSC
     temperature_boil=3134,  # Boiling temperature = 3134 K / Source: RSC
     latent_heat_of_fusion=13800,  # Latent heat of fusion = 13800 J/kg / Source: CRC
@@ -118,7 +118,7 @@ Fe = ChemicalElement(
 Ni = ChemicalElement(
     name="Nickel",
     atomic_number=28,  # Atomic number = 28 / Source: Periodic Table
-    atomic_mass=58.6934 * Constants.u,  # Atomic mass = 58.6934 u / Source: NIST
+    atomic_mass=58.6934 * Constants.amu,  # Atomic mass = 58.6934 amu / Source: NIST
     temperature_melt=1728,  # Melting temperature = 1728 K / Source: RSC
     temperature_boil=3186,  # Boiling temperature = 3186 K / Source: RSC
     latent_heat_of_fusion=17200,  # Latent heat of fusion = 17200 J/kg / Source: CRC
@@ -128,7 +128,7 @@ Ni = ChemicalElement(
 Mo = ChemicalElement(
     name="Molybdenum",
     atomic_number=42,
-    atomic_mass=95.96 * Constants.u,
+    atomic_mass=95.96 * Constants.amu,
     temperature_melt=2896,  # Melting temperature = 2896K (2623°C)
     temperature_boil=4912,  # Boiling temperature = 4912K (4639°C)
     latent_heat_of_fusion=37480,  # Latent heat of fusion = 37.48 kJ/mol
-- 
GitLab